@@ -13,23 +13,25 @@ fn main() {
 
     if cli.help {
         let usage = r###"
-    xplr [FLAG]... [OPTION]... [PATH]"###;
+    xplr [FLAG]... [OPTION]... [PATH] [SELECTION]..."###;
 
         let flags = r###"
-    -                  Reads path from stdin
+    -                  Reads paths from stdin
     --                 Denotes the end of command-line flags and options
         --read-only    Enables read-only mode (config.general.read_only)
     -h, --help         Prints help information
     -V, --version      Prints version information"###;
 
         let options = r###"
-    -c, --config <PATH>            Specifies a custom config file (default is
-                                     "$HOME/.config/xplr/init.lua")
-    -C, --extra-config <PATH>...   Specifies extra config files to load
-        --on-load <MESSAGE>...     Sends messages when xplr loads"###;
+    -c, --config <PATH>             Specifies a custom config file (default is
+                                      "$HOME/.config/xplr/init.lua")
+    -C, --extra-config <PATH>...    Specifies extra config files to load
+        --on-load <MESSAGE>...      Sends messages when xplr loads
+        --force-focus               Focuses on the given <PATH>, even if directory."###;
 
         let args = r###"
-    <PATH>    Path to focus on, or enter if directory"###;
+    <PATH>            Path to focus on, or enter if directory, (default is `.`)
+    <SELECTION>...    Paths to select, requires <PATH> to be set explicitely"###;
 
         let help = format!(
             "xplr {}\n{}\n{}\n\nUSAGE:{}\n\nFLAGS:{}\n\nOPTIONS:{}\n\nARGS:{}",
@@ -65,6 +67,16 @@ fn main() {
 mod tests {
     use assert_cmd::Command;
 
+    #[test]
+    fn test_no_debug_in_lib() {
+        for pat in ["print!", "println!"].iter() {
+            Command::new("grep")
+                .args(&["-R", pat, "src", "--exclude-dir", "bin/"])
+                .assert()
+                .failure();
+        }
+    }
+
     #[test]
     fn test_cli_version() {
         Command::cargo_bin("xplr")
